@@ -24,7 +24,6 @@ from zope.publisher.browser import BrowserView
 from zope.component import getUtility
 from zope.annotation.interfaces import IAnnotations
 from collective.contentlicensing.browser import RSSView as DefaultRSSView
-from collective.contentlicensing.browser.copyrightbyline import CopyrightBylineView as DefaultCopyrightBylineView
 from Products.CMFPlone.utils import getToolByName
 from enpraxis.educommons.utilities.interfaces import IECUtility
 from enpraxis.educommons.annotations.interfaces import ICourseOrderable, ICourseOrder
@@ -159,88 +158,6 @@ class SortedResourceListingView(BrowserView):
         return resources
 
 
-class PositionView(BrowserView):
-
-    def __call__(self):
-        context = self.context
-        position = self.request['position']
-        id = self.request['id']
-        url = self.request['url']
-        
-        if position == 'up':
-            self.moveUp(context, self.request, position, id, url)
-        elif position == 'down':
-            self.moveDown(context, self.request, position, id, url)
-        else:
-            return
-
-
-    def moveUp(self, context, request, position, id, path):
-        objs = self.getNavObjects(context)
-
-        if len(objs) <= 1:
-            return
-
-        if objs[0].getPath() == path:
-            return
-
-        prev_obj = objs[0]
-
-        for obj in objs[1:]:
-            if path == obj.getPath():
-                self.swapPosition(obj.getObject(), prev_obj.getObject())
-                break
-
-            prev_obj = obj
-
-        request.response.redirect('order_courseobjs')
-                
-
-    def moveDown(self, context, request, position, id,path):
-        objs = self.getNavObjects(context)
-        
-        if len(objs) <= 1:
-            return
-
-        prev_obj = None
-        index = 0
-        for obj in objs:
-
-            if len(objs) == index:
-                return
-
-            if prev_obj:
-                self.swapPosition(obj.getObject(), prev_obj.getObject())
-                break
-            if path == obj.getPath():
-                prev_obj = obj
-
-            index += 1
-
-        request.response.redirect('order_courseobjs')
-
-    def swapPosition(self, cur_obj, swp_obj):
-        if ICourseOrderable.providedBy(cur_obj):
-            cobj = ICourseOrder(cur_obj)
-            if ICourseOrderable.providedBy(swp_obj):
-                sobj = ICourseOrder(swp_obj)
-                if cobj.position == sobj.position:
-                    # Objects somehow have the same position
-                    # Force the current object down
-                    cobj.position += 1
-                else:
-                    tmp = cobj.position
-                    cobj.position = sobj.position
-                    sobj.position = tmp
-                cur_obj.reindexObject()
-                swp_obj.reindexObject()
-
-        
-    def getNavObjects(self, context):
-        contentFilter={'path':{'query':'/'.join(context.getPhysicalPath())+'/'},'sort_on':'getObjPositionInCourse'}
-        brains = context.portal_catalog.searchResults(contentFilter)
-        return [brain for brain in brains if not getattr(brain.aq_explicit, 'exclude_from_nav', True)]
-
 class RSSView(DefaultRSSView):
     """ Implements eduCommons RSS view """
 
