@@ -131,7 +131,8 @@ supported_objects_set_recursive_ownership = [
     'ATDocument', 
     'ATFile', 
     'ATImage', 
-    'ATLink'
+    'ATLink',
+    'ATBlob'
 ]
    
 
